<?php
namespace Teknisa\FIS\Modules\Acessorias\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Fis03000DapiMgFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        set_time_limit(0);
    }
    
    /**
     * Executa a procedure para a exportação de DAPI-MG [ARQUIVO_DAPIMG]
     */
    public function callDapiMgProcedure($params) {
        $procedure = new StoredProcedure($this->connection, 'ARQUIVO_DAPIMG');
        
        $procedure->addParam(new Param('P_CDIMPOSTO', Param::PARAM_INPUT, $params["CDIMPOSTO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDINSCESTA', Param::PARAM_INPUT, $params["CDINSCESTA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINICIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFINAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDLIVROMAG', Param::PARAM_INPUT, $params["LIVROMAG"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CAE', Param::PARAM_INPUT, $params["CDDESMEMCAE"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CNAEF', Param::PARAM_INPUT, $params["CDDESMEMCNAEF"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_RECOLHIMENTO', Param::PARAM_INPUT, $params["CDREGIMREC"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ESPEC', Param::PARAM_INPUT, $params["CDREGESPRECOLHI"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_FUNDESE', Param::PARAM_INPUT, $params["CDOPTFUND"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CAFE', Param::PARAM_INPUT, $params["CDMOVCAFE"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_MOVIMENT', Param::PARAM_INPUT, $params["CDDAPIMOV"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_SUBSTR', Param::PARAM_INPUT, $params["CDDAPISUB"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ENCER', Param::PARAM_INPUT, $params["CDINDENCERR"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_PAGMTO', Param::PARAM_INPUT, $params["DTLIMPAG"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQARQMAG', Param::PARAM_INPUT, $params["NRSEQARQMAG"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDTERMACEIT', Param::PARAM_INPUT, $params["CDTERMACEIT"], Param::PARAM_TYPE_STR));
     
        
        $procedure->execute();
    }
    
    /*
     * Função para excluir os dados gerados na procedure de DAPI-MG.
     */
    public function deleteDapiMgData($params) {
        // Query a ser executada.
        $sql = "DELETE FROM ARQMAGNETICO WHERE NRSEQARQMAG = :NRSEQARQMAG AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);
    }

    /*
     * Função para retornar a sigla do estado relacionado a uma inscrição estadual.
     */
    public function getEstadoInscricaoEstadual($params) {
        // Query a ser executada.
        $sql = "SELECT SGESTADO FROM INSCRESTAD WHERE CDEMPRESA = :CDEMPRESA AND CDINSCESTA = :CDINSCESTA AND NRORG = :NRORG";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetch(\PDO::FETCH_ASSOC);
        
    }

    /*
     * Função para retornar os dados gerados na procedure de DAPI-MG.
     */
    public function getDapiMgData($params) {
        
        // Query a ser executada.
        $sql = "SELECT NRSEQARQMAG, NRORDREGARQ, DSREGARQMAG as DSREGARQMAG 
                FROM ARQMAGNETICO 
                WHERE NRORG = :NRORG 
                    AND NRSEQARQMAG = :NRSEQARQMAG 
                ORDER BY NRORDREGARQ, SUBSTR(DSREGARQMAG,1,17)";

        // Prepara o statement da query para execução.
        $statement = $this->connection->prepare($sql);

        // Executa o statement com os paràmetros passados.
        $statement->execute($params);

        // Executa um fetch no primeiro dado, retornando-o.
        return $statement->fetchAll();
    }    
    
    public function findAgendamento() {
        // Query a ser executada.
        $sql = "SELECT 
                    A.NRORG,
                    A.NRAGENDAMENTO,
                    A.CDTELA,
                    A.CDEMPRESA,
                    E.NMEMPRESA,
                    A.CDINSCESTA,
                    A.DTAGENDAMENTO,
                    A.DTINICIAL,
                    A.DTFINAL,
                    A.CDCAMPO1 AS CDLIVROMAG,
                    A.CDCAMPO2 AS CDIMPOSTONFE,
                    DECODE(A.IDPERIAGEN, '0', A.DTINICIAL,
                                   '1', TO_CHAR(SYSDATE, 'DD/MM/YYYY'),
                                   '2', TO_CHAR(ADD_MONTHS(SYSDATE,(-1)), 'DD/MM/YYYY')) AS DTREFINI,
                    L.NMLIVROMAG,
                    I.SGIMPOSTONFE,
                    A.IDPERIAGEN,
                    A.IDSTATUS
                    FROM AGENDOBRIGACESS A,
                    EMPRESA E,
                    LIVROMAGNETICO L,
                    IMPOSTONFE I
                    WHERE CDTELA  = 'FIS03000'
                    AND A.CDEMPRESA = E.CDEMPRESA
                    AND A.CDCAMPO1 = L.CDLIVROMAG
                    AND A.CDCAMPO2 = I.CDIMPOSTONFE";
                    

        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute();
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function insertAgendamento($row) {
        $sql = "INSERT INTO AGENDOBRIGACESS
            ( 
                NRORG,
                NRAGENDAMENTO,
                CDTELA,
            	CDEMPRESA,
                CDINSCESTA,
            	DTAGENDAMENTO,
            	DTINICIAL,
            	DTFINAL,
                IDPERIAGEN,
            	
            	CDCAMPO1,
                CDCAMPO2,
                DTCAMPO1   ) 
             VALUES (
                :NRORG,
                :NRAGENDAMENTO,
                :CDTELA,
                :CDEMPRESA,
                :CDINSCESTA,
                :DTAGENDAMENTO,
                :DTINICIAL,
                :DTFINAL,
                :IDPERIAGEN,
                :CDCAMPO1,
                :CDCAMPO2,
                :DTCAMPO1 )";
                
        $params = array(
            "NRORG"         => $row["NRORG"],
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            "IDPERIAGEN"=> $row["IDPERIAGEN"],
            "CDCAMPO1"  => $row["CDLIVROMAG"],
            "CDCAMPO2"  => $row["CDIMPOSTONFE"],
            "DTCAMPO1"  => $row["DTREFINI"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateAgendamento($row) {
        $sql = "UPDATE AGENDOBRIGACESS
                    SET CDEMPRESA = :CDEMPRESA,
                        CDINSCESTA = :CDINSCESTA,
                    	DTAGENDAMENTO = :DTAGENDAMENTO,
                    	DTINICIAL = :DTINICIAL,
                    	DTFINAL = :DTFINAL,
                    	IDPERIAGEN = :IDPERIAGEN,
                    	CDCAMPO1 = :CDCAMPO1,
                        CDCAMPO2 = :CDCAMPO2,
                        DTCAMPO1 = :DTCAMPO1
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND CDTELA = :CDTELA";
                    
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            
            //Campos da tabela que serão salvos e os campos da declaração
            "DTINICIAL" => $row["DTINICIAL"],
            "DTFINAL"   => $row["DTFINAL"],
            "IDPERIAGEN"=> $row["IDPERIAGEN"],
            "CDCAMPO1"  => $row["CDLIVROMAG"],
            "CDCAMPO2"  => $row["CDIMPOSTONFE"],
            "DTCAMPO1"  => $row["DTREFINI"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateAgendamentoIdStatus($row, $idstatus) {
        $sql = "UPDATE AGENDOBRIGACESS
                    SET IDSTATUS = :IDSTATUS
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND CDTELA = :CDTELA";
                    
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "IDSTATUS"      => $idstatus
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getInscEsta($row) {
        // Query a ser executada.
        $sql = "SELECT CDINSCESTA FROM INSCRESTAD WHERE CDEMPRESA = :CDEMPRESA";

        $params = array(
            'CDEMPRESA' => $row['CDEMPRESA']
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function getAgendamentoInsert($row) {
        // Query a ser executada.
        $sql = "SELECT * FROM AGENDOBRIGACESS 
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";

        $params = array(
            "NRAGENDAMENTO"=>$row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function getConfiguraSMTP($row)  {
        // Query a ser executada.
        $sql = "SELECT * FROM CONFIGURASMTP
                    WHERE NRORG = :NRORG";
        
        $params = array(
            "NRORG"=> $row["NRORG"]
        );
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getContatos($row)  {
        // Query a ser executada.
        $sql = "SELECT * FROM CONTATOAPURAC
                    WHERE NRORG = :NRORG
                    AND CDEMPRESA = :CDEMPRESA
                    AND IDEXPORTAUTO = 'S'";
        
        $params = array(
            "NRORG"     => $row["NRORG"],
            "CDEMPRESA" => $row["CDEMPRESA"]
        );
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function getAgendamentoArquivo($row) {
        $sql = "SELECT * FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function deleteAgendamentoArquivo($row) {
        $sql = "DELETE FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
    }
  
    public function deleteAgendamento($row) {
        // Query a ser executada.
        $sql = "DELETE FROM AGENDOBRIGACESS 
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO";

        $params = array(
            "NRAGENDAMENTO"=>$row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
    }
    
    public function findAgendamentoExec($row) {
        // Query a ser executada.
        $sql = "SELECT 
                    TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI') AS DTATUAL,
                    TO_CHAR(ADD_MONTHS(SYSDATE,(-1)), 'DD/MM/YYYY HH24:MI') AS LAST_MONTH,
                    A.NRAGENDAMENTO,
                    A.CDTELA,
                    A.CDEMPRESA,
                    A.CDINSCESTA,
                    A.DTAGENDAMENTO,
                    A.DTINICIAL,
                    A.DTFINAL,
                    A.CDCAMPO1 AS CDLIVROMAG,
                    L.NMLIVROMAG,
                    A.CDCAMPO2 AS CDIMPOSTONFE,
                    A.DTCAMPO1 AS DTREFINI,
                    A.IDPERIAGEN,
                    A.IDSTATUS
                    FROM AGENDOBRIGACESS A,
                    LIVROMAGNETICO L
                    WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                    AND A.CDCAMPO1 = L.CDLIVROMAG";
        
        $params = array(
            "NRAGENDAMENTO"=> $row["NRAGENDAMENTO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function findParamDeclAcess($row) {
        // Query a ser executada.
        $sql = "SELECT
                 CDCAMPO1    AS CDLIVROMAG,
                 CDCAMPO4    AS CDDESMEMCAE,
                 CDCAMPO5    AS CDDESMEMCNAEF,
                 CDCAMPO6    AS CDREGESPRECOLHI,
                 CDCAMPO7    AS CDOPTFUND,
                 CDCAMPO8    AS CDMOVCAFE,
                 CDCAMPO9    AS CDDAPIMOV,
                 CDCAMPO10   AS CDDAPISUB,
                 CDCAMPO11   AS CDINDENCERR,
                 DTCAMPO1    AS DTLIMPAG,
                 CDCAMPO13   AS CDREGIMREC,
                 CDCAMPO14   AS CDTERMACEIT
             FROM
                 PARAMDECLACES
             WHERE
                 CDTELA =:CDTELA
                 AND CDEMPRESA =:CDEMPRESA";
        
        $params = array(
            "CDTELA"    => $row["CDTELA"],
            "CDEMPRESA" => $row["CDEMPRESA"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetch();
    }
    
    public function getNmEmpresa($row) {
        // Query a ser executada.
        $sql = "SELECT NMEMPRESA FROM EMPRESA
                    WHERE CDEMPRESA = :CDEMPRESA
                    AND NRORG = :NRORG";
        
        $params = array(
            "CDEMPRESA" => $row["CDEMPRESA"],
            "NRORG"     => $row["NRORG"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetch();
    }
    
    public function verAgendamentoArquivo($row) {
        $sql = "SELECT * FROM ARQUIOBRIGACESS
                WHERE NRAGENDAMENTO = :NRAGENDAMENTO
                AND NMARQUIVO = :NMARQUIVO";
        
        $params = array(
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "NMARQUIVO"     => $row["NMARQUIVO"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        return $std->fetchAll();
    }
    
    public function insertAgendamentoArquivo($row) {
        $sql = "INSERT INTO ARQUIOBRIGACESS
            ( 
                NRORG,
                NRARQUIVO,
                NRAGENDAMENTO,
                CDTELA,
                CDEMPRESA,
                CDINSCESTA,
                DTAGENDAMENTO,
                DTEXECAGEND,
                NMARQUIVO,
                NMPATHARQ
            )
             VALUES (
                :NRORG,
                :NRARQUIVO,
                :NRAGENDAMENTO,
                :CDTELA,
                :CDEMPRESA,
                :CDINSCESTA,
                :DTAGENDAMENTO,
                :DTEXECAGEND,
                :NMARQUIVO,
                :NMPATHARQ  )";
        
        $params = array(
            "NRORG"         => $row["NRORG"],
            "NRARQUIVO"     => $row["NRARQUIVO"],
            "NRAGENDAMENTO" => $row["NRAGENDAMENTO"],
            "CDTELA"        => $row["CDTELA"],
            "CDEMPRESA"     => $row["CDEMPRESA"],
            "CDINSCESTA"    => $row["CDINSCESTA"],
            "DTAGENDAMENTO" => $row["DTAGENDAMENTO"],
            "DTEXECAGEND"   => $row["DTEXECAGEND"],
            "NMARQUIVO"     => $row["NMARQUIVO"],
            "NMPATHARQ"     => $row["NMPATHARQ"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}